| Title: | Case Ascertainment Model |
|---|---|
| Description: | This pacakge implements a case asecertainment model. |
| Authors: | Pierre Nouvellet [aut], Sangeeta Bhatia [aut, cre] (ORCID: <https://orcid.org/0000-0001-6525-101X>) |
| Maintainer: | Sangeeta Bhatia <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-09 07:37:55 UTC |
| Source: | https://github.com/mrc-ide/ascertainr |
Estimate case ascertainment ratio
ascertainment(cfr_distr, death_to_case)ascertainment(cfr_distr, death_to_case)
cfr_distr |
|
death_to_case |
Augment the time series of cases for the days ahead to be able to project deaths.
augment_cases(cases, previous, ndays, nsim = 10000)augment_cases(cases, previous, ndays, nsim = 10000)
Augmentation of case data for the
next ndays days involves
drawing samples from a distribution
(here gamma distribution)
with parameters estimated from the
last previous days.
Matrix of observed and augmented cases. Dimensions of this matrix are (2 * nsim) X (previous) where the observed values are repeated across
Sangeeta Bhatia
Estimate epidemic size from the present time minus the mean delay between case and death up to present
episize_after_mu(cases, rho)episize_after_mu(cases, rho)
Sangeeta Bhatia
Estimate size of the epidemic upto the present time minus the mean delay from case to death.
episize_before_mu(deaths, mu_delta, cfr_distr)episize_before_mu(deaths, mu_delta, cfr_distr)
Sangeeta Bhatia
Project the number of deaths
project_deaths(augmented_cases, weights, trunc, ndays, nsim, deaths_to_cases)project_deaths(augmented_cases, weights, trunc, ndays, nsim, deaths_to_cases)
Sangeeta Bhatia
Estimate ratio if deaths to reported cases
ratio_deaths_cases(wtd_incid, deaths, nsamples = 10000, twindow = 7)ratio_deaths_cases(wtd_incid, deaths, nsamples = 10000, twindow = 7)
wtd_incid |
|
deaths |
|
nsamples |
|
twindow |
Returns
weighted_incid(incid, weights, trunc)weighted_incid(incid, weights, trunc)
incid |
incidence time series as a T X 1 matrix |
weights |
Discrete probability distribution of the reporting to death delay |
T X 1 matrix incidence weighted by the delay distribution.
Sangeeta Bhatia